@@ -3,9 +3,10 @@
 # Function to perform the unpredictable binomial MaxSPRT surveillance - Version edited at Jan-15-2015
 # -------------------------------------------------------------------------
 
-AnalyzeSetUp.Binomial<- function(name,N="n",alpha=0.05,zp="n",pp="n",M=1,AlphaSpendType="optimal",power=0.9,RR=2,ConfIntWidth="n",gama=0.9,R0=1,ObjectiveMin="ETimeToSignal",rho=0.5,title="n",address="n",Tailed="upper")
+AnalyzeSetUp.Binomial<- function(name,N="n",alpha=0.05,zp="n",pp="n",M=1,AlphaSpendType="optimal",power=0.9,RR=2,ConfIntWidth="n",ConfTimes=1,Gamma=0.9,R0=1,ObjectiveMin="ETimeToSignal",rho=0.5,title="n",address="n",Tailed="upper")
 {
 
+gama<- Gamma
 if(Tailed!="upper"){stop("For this version of the Sequential package, AnalyzeSetUp.Binomial works only for 'Tailed=upper'.",call. =FALSE)}
 
 Tailed<- 1
@@ -235,8 +236,8 @@ sum_sa<- sa%*%(upper.tri(matrix(0,length(sa),length(sa)),diag=T))
 
 if(AlphaSpendType=="optimal"){#3
 
-res<- Optimal.Binomial(Objective=ObjectiveMin,N,z,p="n",alpha,power,RR,GroupSizes="n",Tailed= "upper",ConfIntWidth,gama,R0); sum_sa<- res$optimal_alpha_spending; N<- length(sum_sa)
-
+res<- Optimal.Binomial(Objective=ObjectiveMin,N,z,p="n",alpha,power,RR,GroupSizes="n",Tailed= "upper",ConfIntWidth,ConfTimes,Gamma,R0); sum_sa<- res$optimal_alpha_spending; N<- length(sum_sa)
+if(res$solved==-1){stop("For these input parameters, the R simplex function cannot find the optimal alpha spending. Select a different parametrization, e.g. a different power, or choose between AlphaSpendType='power-type' and AlphaSpendType='Wald'.",call. =FALSE)}
 y<- qbinom(1-alpha,N,1/(1+z/R0)); y<- y+1 # auxiliar variable
 if(y<N){absorb1<- c(seq(2,y),y,seq(y+1,N))}else{absorb1<- c(seq(2,y),y)}; absorb1<- c(absorb1,0,0)
                              }#3
